@@ -11,3 +11,8 @@ def captureImg(filepath):
 def blur(image, intensity: tuple):
     blurred = cv2.GaussianBlur(image, intensity, cv2.BORDER_DEFAULT)
     return blurred
+
+
+def blur2(image, intensity: int):
+    blurred = cv2.GaussianBlur(image, (intensity, intensity), cv2.BORDER_DEFAULT)
+    return blurred
